summaryrefslogtreecommitdiffstats
path: root/lib/kross/runner
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-01-19 23:57:47 -0600
committerTimothy Pearson <[email protected]>2013-01-19 23:57:47 -0600
commit6ec5cc8d82b29c330def669cf20534cadd2cf29e (patch)
tree7e66b929b5455837f22ea54ed91fc9af6f64f7bf /lib/kross/runner
parent68a4fdfd2c2b70a7c22c4c6d6c916e604a0efac2 (diff)
downloadkoffice-6ec5cc8d82b29c330def669cf20534cadd2cf29e.tar.gz
koffice-6ec5cc8d82b29c330def669cf20534cadd2cf29e.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'lib/kross/runner')
-rw-r--r--lib/kross/runner/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kross/runner/main.cpp b/lib/kross/runner/main.cpp
index fcff2bb0..74c84cf3 100644
--- a/lib/kross/runner/main.cpp
+++ b/lib/kross/runner/main.cpp
@@ -45,7 +45,7 @@
#define ERROR_UNHALDEDEXCEPTION -5
#define ERROR_EXCEPTION -6
-KApplication* app = 0;
+TDEApplication* app = 0;
int runScriptFile(const TQString& scriptfile)
{
@@ -125,8 +125,8 @@ int main(int argc, char **argv)
return ERROR_HELP;
}
- // Create KApplication instance.
- app = new KApplication( /* allowStyles */ true, /* GUIenabled */ true );
+ // Create TDEApplication instance.
+ app = new TDEApplication( /* allowStyles */ true, /* GUIenabled */ true );
//TQString interpretername = args->getOption("interpreter");
//TQString scriptfilename = args->getOption("scriptfile");
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
break;
}
// Free the KApplication instance and exit the program.
delete app;
return result;
}
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
break;
}
- // Free the KApplication instance and exit the program.
+ // Free the TDEApplication instance and exit the program.
delete app;
return result;